<!--- 
	csw-readmore.cfc
	
	This is the core rendering for the Read More Formatted Text Block Without Header widget.
	
	Version: [2018-01-17 10:15]
--->

<cfcomponent displayname="csw-readMore" output="false" hint="Common Read More Functions" extends="_cs_widgets._common.csw-common">

	<cffunction name="loadResources" access="public" output="Yes" returntype="void">
		<cfscript>
			// load Resources		
			Server.CommonSpot.udf.resources.loadResources("JQuery");
			Server.CommonSpot.udf.resources.loadResources("FontAwesome");
			Server.CommonSpot.udf.resources.loadResources("ReadMoreJS");
			
			Server.CommonSpot.udf.resources.loadResources("cswCommonStyles");
			Server.CommonSpot.udf.resources.loadResources("cswTextStyles");
			Server.CommonSpot.udf.resources.loadResources("cswButtonStyles");
			Server.CommonSpot.udf.resources.loadResources("cswReadMore");

			// If a custom stylesheets have been registered, go ahead and load them.
			if( StructKeyExists(Request.Site.CS_Resources.Resources_by_name,'cswCommonStyles_custom') )
				Server.CommonSpot.udf.resources.loadResources("cswCommonStyles_custom");
			if( StructKeyExists(Request.Site.CS_Resources.Resources_by_name,'cswTextStyles_custom') )
				Server.CommonSpot.udf.resources.loadResources("cswTextStyles_custom");
			if( StructKeyExists(Request.Site.CS_Resources.Resources_by_name,'cswButtonStyles_custom') )
				Server.CommonSpot.udf.resources.loadResources("cswButtonStyles_custom");
			if( StructKeyExists(Request.Site.CS_Resources.Resources_by_name,'cswReadMore_custom') )
				Server.CommonSpot.udf.resources.loadResources("cswReadMore_custom");
		</cfscript>
	</cffunction>

	<cffunction name="loadProperties" access="public" returntype="any" output="Yes">
		<cfargument name="elementInfo" type="struct" required="Yes">
		<cfargument name="rhCaller" type="struct" required="false" default="#StructNew()#">
		<cfargument name="showDataError" type="boolean" required="false" default="true">

		<cfscript>
			var widgetMetadataFormName = "CSW ReadMore";
			var props = StructNew();
			var rhMetadata = arguments.ElementInfo.RenderHandlerMetaData;
			var widgetData = StructNew();


			// Check for Props and Layout Binding
			if( NOT hasPropsLayoutBinding(ElementInfo=arguments.elementInfo,metadataFormName=widgetMetadataFormName,rhCaller=arguments.rhCaller) )
				return props;

			// 
			// Get Metadata (Core Read More metadata)
			// ------------------------------------------
			widgetData = rhMetadata[widgetMetadataFormName];
			
			
			// Set props defaults
			props.startExpanded = false;
			props.themeClass = "";

			// Theme
			if( StructKeyExists(widgetData,"Theme") )
				props.themeClass = TRIM(widgetData.Theme);

			/**************************************/
			/******  GENERAL PROPERTIES TAB  ******/
			/**************************************/

			// Collapse Mode
			props.Collapsed_Mode = getStandardField( widgetData=widgetData, field='Collapse_Mode', defValue='height' );	

			// Collapsed Heights
			props.Collapsed_Height = getStandardField( widgetData=widgetData, field='Collapsed_Height', defValue='200' );	

			// Collapse Text
			props.Collapsed_Text = getStandardField( widgetData=widgetData, field='Collapse_Text' );	

			// Collapse Tag
			props.Collapsed_Tag = getStandardField(widgetData=widgetData, field='Collapse_Tag' );				
			
			// Collapse Placement
			props.Collapsed_Placement = getStandardField(widgetData=widgetData, field='Collapse_Placement' );				
			
			// Collapse Occurence
			props.occurence = getStandardField(widgetData=widgetData, field='occurence' );				

			// Speed
			props.Speed = getStandardField( widgetData=widgetData, field='Speed', defValue='100' );	
			
			// Options Checkbox
			if( StructKeyExists(widgetData,"options") ) 
			{
				if( FindNoCase("startExpanded",widgetData.options))
					props.startExpanded = true; 
			}
			
			// More_Link_Text
			props.moreLinkText = getStandardField( widgetData=widgetData, field='More_Link_Text', defValue='More' );	
			
			// Less_Link_Text
			props.lessLinkText = getStandardField( widgetData=widgetData, field='Less_Link_Text', defValue='Less' );	
			

			/**************************************/
			/**** LINK/BUTTON PROPERTIES TAB ******/
			/**************************************/

			// Button Type
			props.buttonType = getStandardField( widgetData=widgetData, field='Button_Type', defValue='cswButton' );

			// Button (STRUCT)
			props.button = getFieldSettings(widgetData=widgetData, field='Button', defShow='0', defColor='white', defBgColor='black', defSize='cswBtnSize-normal', defStyle='cswBtn-filled');

			// Button_Corners
			props.buttonCorners = getStandardField( widgetData=widgetData, field='Button_Corners', defValue='cswBtn-rounded' );

			// Link (STRUCT)
			props.link = getFieldSettings(widgetData=widgetData, field='Link', defShow='0', defColor='inherit', defSize='cswBtnSize-normal', defStyle='');

			// Icon
			props.buttonIcon = ''; // Using both a More Icon and a Less Icon instead of a single Button Icon field
			
			// More Link Icon
			props.moreLinkIcon = getStandardField( widgetData=widgetData, field='More_Link_Icon' );
			
			// Less Link Icon
			props.lessLinkIcon = getStandardField( widgetData=widgetData, field='Less_Link_Icon' );

			return props;
		</cfscript>
		
	</cffunction>
	
	<!----------------------------------------
		Get Read More and Less Links (STRUCT)
	----------------------------------------->
	<cffunction name="getReadMoreAndLessLinks" access="public" output="Yes" returntype="struct">
		<cfargument name="dataStruct" type="struct" required="No" default="#StructNew()#">
		<cfargument name="propsStruct" type="struct" required="No" default="#StructNew()#">
		
		<cfscript>
			var rtnStruct = StructNew();
			var data = arguments.dataStruct;
			var props = arguments.propsStruct;
			
			// Set the default link
			props.linkURL = '##';
			props.linkText = '';
			props.buttonIcon = '';
			
			// Render The MORE Button/Link
			if ( StructKeyExists(props,"moreLinkText") )
				props.linkText = JSStringFormat(props.moreLinkText);
			if ( StructKeyExists(props,"moreLinkIcon") )
				props.buttonIcon = props.moreLinkIcon;
				
			// Get the MORE Button/Link HTML
			rtnStruct.moreLinkHTML = renderButtonHTML(data, props);
			
			
			// Render the LESS Button/Link
			if ( StructKeyExists(props,"lessLinkText") )
				props.linkText = JSStringFormat(props.lessLinkText);
			if ( StructKeyExists(props,"lessLinkIcon") )
				props.buttonIcon = props.lessLinkIcon;
		
			// Get the LESS Button/Link HTML
			rtnStruct.lessLinkHTML = renderButtonHTML(data, props);
			
			return rtnStruct;
		</cfscript>
	</cffunction>

	<!----------------------------------------
		Render Link/Button HTML
	----------------------------------------->
	<cffunction name="renderButtonHTML" access="public" output="Yes" returntype="string">
		<cfargument name="dataStruct" type="struct" required="Yes">
		<cfargument name="propsStruct" type="struct" required="Yes">

		<cfscript>
			var data = arguments.dataStruct;
			var props = arguments.propsStruct;
			var retHTML = '';
			var arg = '';

			// Capture the standard Button/Link HTML output
			savecontent variable="retHTML" {
				WriteOutput(#renderButton( data, props )#);
			}
			
			// Remove newlines or the carriage returns
			retHTML = reReplace(trim(retHTML),"(\n|\r)","","ALL");
			
			return retHTML;
		</cfscript>
	</cffunction>
	
</cfcomponent>